@@ -1293,14 +1293,7 @@ gvm_device_mounted (const char *udi)
 static gboolean
 gvm_device_mount (const char *udi, gboolean interactive)
 {
-	char *command, *mount_point, *fstype;
 	struct _MountPolicy *policy;
-	DBusMessage *dmesg, *reply;
-	dbus_uint64_t size;
-	GPtrArray *options;
-	DBusError error;
-	gboolean retval;
-	char uid[32];
 	
 	dbg ("mounting %s...\n", udi);
 	
@@ -1310,6 +1303,9 @@ gvm_device_mount (const char *udi, gboolean interactive)
 	}
 	
 	if (gnome_mount != NULL) {
+		gboolean retval;
+		char *command;
+		
 		policy = g_new (struct _MountPolicy, 1);
 		policy->udi = g_strdup (udi);
 		policy->apply = interactive;
@@ -1333,6 +1329,13 @@ gvm_device_mount (const char *udi, gboolean interactive)
 		
 		return retval;
 	} else {
+		char *mount_point, *fstype;
+		DBusMessage *dmesg, *reply;
+		dbus_uint64_t size;
+		GPtrArray *options;
+		DBusError error;
+		char uid[32];
+		
 		if (!(dmesg = dbus_message_new_method_call ("org.freedesktop.Hal", udi,
 							    "org.freedesktop.Hal.Device.Volume",
 							    "Mount"))) {
@@ -1340,27 +1343,28 @@ gvm_device_mount (const char *udi, gboolean interactive)
 			return FALSE;
 		}
 		
+		options = g_ptr_array_new ();
 		size = libhal_device_get_property_uint64 (hal_ctx, udi, "volume.size", NULL);
-		if (!(fstype = libhal_device_get_property_string (hal_ctx, udi, "volume.fstype", NULL)))
-			fstype = g_strdup ("");
+		if ((fstype = libhal_device_get_property_string (hal_ctx, udi, "volume.fstype", NULL))) {
+			snprintf (uid, sizeof (uid) - 1, "uid=%u", getuid ());
+			
+			if (!strcmp (fstype, "vfat")) {
+				g_ptr_array_add (options, "shortname=winnt");
+				g_ptr_array_add (options, uid);
+				
+				if (size <= (512 * 1024 * 1024))
+					g_ptr_array_add (options, "sync");
+			} else if (!strcmp (fstype, "iso9660")) {
+				g_ptr_array_add (options, uid);
+			} else if (!strcmp (fstype, "udf")) {
+				g_ptr_array_add (options, uid);
+			}
+			
+			g_free (fstype);
+		}
 		
 		mount_point = "";
-		
-		snprintf (uid, sizeof (uid) - 1, "uid=%u", getuid ());
-		
-		options = g_ptr_array_new ();
-		
-		if (!strcmp (fstype, "vfat")) {
-			g_ptr_array_add (options, "shortname=winnt");
-			g_ptr_array_add (options, uid);
-			
-			if (size <= (512 * 1024 * 1024))
-				g_ptr_array_add (options, "sync");
-		} else if (!strcmp (fstype, "iso9660")) {
-			g_ptr_array_add (options, uid);
-		} else if (!strcmp (fstype, "udf")) {
-			g_ptr_array_add (options, uid);
-		}
+		fstype = "";
 		
 		if (!dbus_message_append_args (dmesg, DBUS_TYPE_STRING, &mount_point, DBUS_TYPE_STRING, &fstype,
 					       DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options->pdata, options->len,
@@ -1371,7 +1375,6 @@ gvm_device_mount (const char *udi, gboolean interactive)
 		}
 		
 		g_ptr_array_free (options, TRUE);
-		g_free (fstype);
 		
 		policy = g_new (struct _MountPolicy, 1);
 		policy->udi = g_strdup (udi);
@@ -2525,8 +2528,8 @@ main (int argc, char *argv[])
 	textdomain (PACKAGE);
 	
 #ifdef GNOME_PARAM_GOPTION_CONTEXT
-	context = g_option_context_new (PACKAGE);
-	g_option_context_add_main_entries (context, options, NULL);
+	ctx = g_option_context_new (PACKAGE);
+	g_option_context_add_main_entries (ctx, options, NULL);
 #endif
 	
 	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
